@@ -1,5 +1,5 @@
 """Module providing input/output functions."""
-from biopsykit.io import ecg, eeg, nilspod, saliva, sleep, sleep_analyzer
+from biopsykit.io import carwatch_logs, ecg, eeg, nilspod, saliva, sleep, sleep_analyzer
 from biopsykit.io.io import (
     convert_time_log_datetime,
     load_codebook,
@@ -22,6 +22,7 @@ __all__ = [
     "convert_time_log_datetime",
     "write_pandas_dict_excel",
     "write_result_dict",
+    "carwatch_logs",
     "ecg",
     "eeg",
     "nilspod",
